@@ -17,6 +17,7 @@
 
 import os
 import shutil
+import stat
 import sys
 import tarfile
 from subprocess import Popen, PIPE
@@ -36,9 +37,10 @@ pjoin = os.path.join
 # Constants
 #-----------------------------------------------------------------------------
 
-bundled_version = (2,2,0)
+bundled_version = (3,2,2)
 libzmq = "zeromq-%i.%i.%i.tar.gz" % (bundled_version)
 libzmq_url = "http://download.zeromq.org/" + libzmq
+# util no longer used
 util = "util-linux-2.21.tar.gz"
 util_url = "http://www.kernel.org/pub/linux/utils/util-linux/v2.21/" + util
 
@@ -113,6 +115,8 @@ def stage_platform_hpp(zmqroot):
                 platform_dir = pjoin(HERE, 'include_darwin')
             elif sys.platform.startswith('freebsd'):
                 platform_dir = pjoin(HERE, 'include_freebsd')
+            elif sys.platform.startswith('linux-armv'):
+                platform_dir = pjoin(HERE, 'include_linux-armv')
             else:
                 platform_dir = pjoin(HERE, 'include_linux')
         else:
@@ -122,6 +126,9 @@ def stage_platform_hpp(zmqroot):
     shutil.copy(pjoin(platform_dir, 'platform.hpp'), platform_hpp)
 
 
+# fetch/patch_uuid no longer needed for libzmq >= 3
+
+
 def fetch_uuid(savedir):
     """download, extract, and patch libuuid sources"""
     dest = pjoin(savedir, 'uuid')
@@ -180,7 +187,7 @@ def copy_and_patch_libzmq(ZMQ, libzmq):
         return
     # copy libzmq into zmq for bdist
     local = localpath('zmq',libzmq)
-    if ZMQ is None and not os.path.exists(local):
+    if not ZMQ and not os.path.exists(local):
         fatal("Please specify zmq prefix via `setup.py configure --zmq=/path/to/zmq` "
         "or copy libzmq into zmq/ manually prior to running bdist.")
     try:
@@ -195,6 +202,10 @@ def copy_and_patch_libzmq(ZMQ, libzmq):
             "or copy libzmq into zmq/ manually.")
     
     if sys.platform == 'darwin':
+        # chmod u+w on the lib,
+        # which can be user-read-only for some reason
+        mode = os.stat(local).st_mode
+        os.chmod(local, mode | stat.S_IWUSR)
         # patch install_name on darwin, instead of using rpath
         cmd = ['install_name_tool', '-id', '@loader_path/../%s'%libzmq, local]
         try:
