@@ -11,13 +11,15 @@
 # Imports
 #-----------------------------------------------------------------------------
 
+import gc
 import sys
 import time
 from threading import Thread, Event
 
 import zmq
-from zmq.tests import BaseZMQTestCase, have_gevent, GreenTest, skip_green
-from zmq.tests import BaseZMQTestCase
+from zmq.tests import (
+    BaseZMQTestCase, have_gevent, GreenTest, skip_green, PYPY, SkipTest,
+)
 
 
 #-----------------------------------------------------------------------------
@@ -38,13 +40,21 @@ class TestContext(BaseZMQTestCase):
         self.assert_(isinstance(c3, self.Context))
         del c3
 
+    def test_dir(self):
+        ctx = self.Context()
+        self.assertTrue('socket' in dir(ctx))
+        if zmq.zmq_version_info() > (3,):
+            self.assertTrue('IO_THREADS' in dir(ctx))
+        ctx.term()
+
+
     def test_term(self):
         c = self.Context()
         c.term()
         self.assert_(c.closed)
 
     def test_fail_init(self):
-        self.assertRaisesErrno(zmq.EINVAL, self.Context, 0)
+        self.assertRaisesErrno(zmq.EINVAL, self.Context, -1)
     
     def test_term_hang(self):
         rep,req = self.create_bound_pair(zmq.ROUTER, zmq.DEALER)
@@ -79,10 +89,10 @@ class TestContext(BaseZMQTestCase):
         """setting socket options with ctx attributes"""
         ctx = self.Context()
         ctx.linger = 5
-        self.assertEquals(ctx.linger, 5)
+        self.assertEqual(ctx.linger, 5)
         s = ctx.socket(zmq.REQ)
-        self.assertEquals(s.linger, 5)
-        self.assertEquals(s.getsockopt(zmq.LINGER), 5)
+        self.assertEqual(s.linger, 5)
+        self.assertEqual(s.getsockopt(zmq.LINGER), 5)
         s.close()
         # check that subscribe doesn't get set on sockets that don't subscribe:
         ctx.subscribe = b''
@@ -132,11 +142,17 @@ class TestContext(BaseZMQTestCase):
     
     def test_gc(self):
         """test close&term by garbage collection alone"""
+        if PYPY:
+            raise SkipTest("GC doesn't work ")
+            
         # test credit @dln (GH #137):
-        def gc():
-            ctx = self.Context()
-            s = ctx.socket(zmq.PUSH)
-        t = Thread(target=gc)
+        def gcf():
+            def inner():
+                ctx = self.Context()
+                s = ctx.socket(zmq.PUSH)
+            inner()
+            gc.collect()
+        t = Thread(target=gcf)
         t.start()
         t.join(timeout=1)
         self.assertFalse(t.is_alive(), "Garbage collection should have cleaned up context")
@@ -174,7 +190,7 @@ class TestContext(BaseZMQTestCase):
             try:
                 s.recv()
             except zmq.ZMQError as e:
-                self.assertEquals(e.errno, zmq.ETERM)
+                self.assertEqual(e.errno, zmq.ETERM)
                 return
             finally:
                 s.close()
