@@ -1,21 +1,11 @@
+#-----------------------------------------------------------------------------
+#  Copyright (c) 2010-2012 Brian Granger, Min Ragan-Kelley
 #
-#    Copyright (c) 2010 Min Ragan-Kelley
-#
-#    This file is part of pyzmq.
-#
-#    pyzmq is free software; you can redistribute it and/or modify it under
-#    the terms of the Lesser GNU General Public License as published by
-#    the Free Software Foundation; either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    pyzmq is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    Lesser GNU General Public License for more details.
-#
-#    You should have received a copy of the Lesser GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#  This file is part of pyzmq
 #
+#  Distributed under the terms of the New BSD License.  The full license is in
+#  the file COPYING.BSD, distributed as part of this software.
+#-----------------------------------------------------------------------------
 
 #-----------------------------------------------------------------------------
 # Imports
@@ -28,7 +18,8 @@ import threading
 import zmq
 from zmq.tests import BaseZMQTestCase
 from zmq.eventloop import ioloop
-from zmq.utils.strtypes import asbytes as b
+from zmq.eventloop.minitornado.ioloop import _Timeout
+
 
 #-----------------------------------------------------------------------------
 # Tests
@@ -78,10 +69,11 @@ class TestIOLoop(BaseZMQTestCase):
     
     def test_timeout_compare(self):
         """test timeout comparisons"""
-        t = ioloop._Timeout(1,2)
-        t2 = ioloop._Timeout(1,3)
-        self.assertEquals(t < t2, id(t) < id(t2))
-        t2 = ioloop._Timeout(2,1)
+        loop = ioloop.IOLoop()
+        t = _Timeout(1, 2, loop)
+        t2 = _Timeout(1, 3, loop)
+        self.assertEqual(t < t2, id(t) < id(t2))
+        t2 = _Timeout(2,1, loop)
         self.assertTrue(t < t2)
 
     def test_poller_events(self):
@@ -91,18 +83,18 @@ class TestIOLoop(BaseZMQTestCase):
         poller.register(req, ioloop.IOLoop.READ)
         poller.register(rep, ioloop.IOLoop.READ)
         events = dict(poller.poll(0))
-        self.assertEquals(events.get(rep), None)
-        self.assertEquals(events.get(req), None)
+        self.assertEqual(events.get(rep), None)
+        self.assertEqual(events.get(req), None)
         
         poller.register(req, ioloop.IOLoop.WRITE)
         poller.register(rep, ioloop.IOLoop.WRITE)
         events = dict(poller.poll(1))
-        self.assertEquals(events.get(req), ioloop.IOLoop.WRITE)
-        self.assertEquals(events.get(rep), None)
+        self.assertEqual(events.get(req), ioloop.IOLoop.WRITE)
+        self.assertEqual(events.get(rep), None)
         
         poller.register(rep, ioloop.IOLoop.READ)
-        req.send(b('hi'))
+        req.send(b'hi')
         events = dict(poller.poll(1))
-        self.assertEquals(events.get(rep), ioloop.IOLoop.READ)
-        self.assertEquals(events.get(req), None)
+        self.assertEqual(events.get(rep), ioloop.IOLoop.READ)
+        self.assertEqual(events.get(req), None)
 
